@@ -105,14 +105,19 @@ CONFIGURATIONS = (
     ' go to the Amazon EMR Documentation: </p>'
     '<p>http://docs.aws.amazon.com/ElasticMapReduce/latest/Applications/'
     'emr-configure-apps.html</p>'
-    )
+)
 
 INSTANCE_GROUPS = (
     '<p>A specification of the number and type'
     ' of Amazon EC2 instances to create instance groups in a cluster.</p>'
     '<p> Each instance group takes the following parameters: '
     '<code>[Name], InstanceGroupType, InstanceType, InstanceCount,'
-    ' [BidPrice]</code></p>')
+    ' [BidPrice], [EbsConfiguration]</code>. [EbsConfiguration] is optional.'
+    ' EbsConfiguration takes the following parameters: <code>EbsOptimized</code>'
+    ' and <code>EbsBlockDeviceConfigs</code>. EbsBlockDeviceConfigs is an array of EBS volume'
+    ' specifications, which takes the following parameters : <code>([VolumeType], '
+    ' [SizeInGB], Iops)</code> and VolumesPerInstance which is the count of EBS volumes'
+    ' per instance with this specification.</p>')
 
 INSTANCE_TYPE = (
     '<p>Shortcut option for --instance-groups. A specification of the '
@@ -138,8 +143,8 @@ EC2_ATTRIBUTES = (
     ' EmrManagedMasterSecurityGroup, EmrManagedSlaveSecurityGroup,'
     ' AdditionalMasterSecurityGroups and AdditionalSlaveSecurityGroups.'
     ' AvailabilityZone and Subnet cannot be specified together.'
-    ' To create the default instance profile <code>'
-    + EC2_ROLE_NAME + '</code>,'
+    ' To create the default instance profile <code>' +
+    EC2_ROLE_NAME + '</code>,'
     ' use <code>aws emr create-default-roles</code> command. </p>'
     'This command will also create the default EMR service role '
     '<code>' + EMR_ROLE_NAME + '</code>.'
@@ -331,3 +336,8 @@ CREATE_CLUSTER_DESCRIPTION = (
     'Values for variables Instance Profile (under EC2 Attributes),'
     ' Service Role, Log URI, and Key Name (under EC2 Attributes) can be set in'
     ' the AWS CLI config file using the "aws configure set" command.\n')
+
+SECURITY_CONFIG = (
+    '<p>The name of a security configuration in the AWS account. '
+    'Use <code>list-security-configurations</code> to get a list of available '
+    'security configurations.</p>')
\ No newline at end of file
